PyBaccarat: pybaccarat.baccarat.Scoreboard Class Reference

PyBaccarat visit the ministry of silly walks

Public Member Functions | Public Attributes | Static Public Attributes | List of all members
pybaccarat.baccarat.Scoreboard Class Reference

TBD board0 = "big road" board1 = "big eye boy" board2 = "small road" board3 = "cockroach pig". More...

Inheritance diagram for pybaccarat.baccarat.Scoreboard:

## Public Member Functions
def | __init__ (self, type, table_size=6)
def | get_array (self)
def | get_horiz_count (self)
def | set_debug (self, dbug=True)
def | mark (self, marker)
| Mark the scoreboard. More...
def | get_cs_mark (self, main_array)
def | get_peek_B_array (self, arr)
def | print_lines (self)
def | __init__ (self, type, table_size=6)
def | get_array (self)
def | get_horiz_count (self)
def | set_debug (self, dbug=True)
def | mark (self, marker)
| Mark the scoreboard. More...
def | get_cs_mark (self, main_array)
def | get_peek_B_array (self, arr)
def | print_lines (self)

## Public Attributes
| board_type
| h_array
| horiz_count
| lines

## Static Public Attributes
string | RED_SAME = 's'
string | BLUE_CHOP = 'C'

## Detailed Description

TBD board0 = "big road" board1 = "big eye boy" board2 = "small road" board3 = "cockroach pig".

## Member Function Documentation

## ◆ mark() [1/2]

def pybaccarat.baccarat.Scoreboard.mark | ( |  | self,
|  |  | marker
| ) |  |

Mark the scoreboard.

For board type 0 marker should be "B" or "P" for Banker or Player. For board types 1,2,3 marker should be "C" or "s" for Chop or Same.

Parameters

  self | this instance of the class
  marker | single char

## ◆ mark() [2/2]

def pybaccarat.baccarat.Scoreboard.mark | ( |  | self,
|  |  | marker
| ) |  |

Mark the scoreboard.

For board type 0 marker should be "B" or "P" for Banker or Player. For board types 1,2,3 marker should be "C" or "s" for Chop or Same.

Parameters

  self | this instance of the class
  marker | single char

The documentation for this class was generated from the following file:

- build/lib/pybaccarat/baccarat.py